# coding: utf-8

"""
    cloudFPGA Resource Manager API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.8
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from swagger_client.api_client import ApiClient


class ClustersApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def cf_manager_rest_api_delete_cluster(self, username, password, cluster_id, **kwargs):  # noqa: E501
        """Delete a cluster  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cf_manager_rest_api_delete_cluster(username, password, cluster_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str username: OpenStack username (required)
        :param str password: OpenStack password (required)
        :param int cluster_id: ID of a cluster (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.cf_manager_rest_api_delete_cluster_with_http_info(username, password, cluster_id, **kwargs)  # noqa: E501
        else:
            (data) = self.cf_manager_rest_api_delete_cluster_with_http_info(username, password, cluster_id, **kwargs)  # noqa: E501
            return data

    def cf_manager_rest_api_delete_cluster_with_http_info(self, username, password, cluster_id, **kwargs):  # noqa: E501
        """Delete a cluster  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cf_manager_rest_api_delete_cluster_with_http_info(username, password, cluster_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str username: OpenStack username (required)
        :param str password: OpenStack password (required)
        :param int cluster_id: ID of a cluster (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['username', 'password', 'cluster_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cf_manager_rest_api_delete_cluster" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'username' is set
        if ('username' not in params or
                params['username'] is None):
            raise ValueError("Missing the required parameter `username` when calling `cf_manager_rest_api_delete_cluster`")  # noqa: E501
        # verify the required parameter 'password' is set
        if ('password' not in params or
                params['password'] is None):
            raise ValueError("Missing the required parameter `password` when calling `cf_manager_rest_api_delete_cluster`")  # noqa: E501
        # verify the required parameter 'cluster_id' is set
        if ('cluster_id' not in params or
                params['cluster_id'] is None):
            raise ValueError("Missing the required parameter `cluster_id` when calling `cf_manager_rest_api_delete_cluster`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cluster_id' in params:
            path_params['cluster_id'] = params['cluster_id']  # noqa: E501

        query_params = []
        if 'username' in params:
            query_params.append(('username', params['username']))  # noqa: E501
        if 'password' in params:
            query_params.append(('password', params['password']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/clusters/{cluster_id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def cf_manager_rest_api_extend_cluster(self, body, username, password, cluster_id, **kwargs):  # noqa: E501
        """Add nodes to an existing cluster  # noqa: E501

        This adds nodes to an existing cluster, as specified in the parameter `cluster_details`.  **Details** on how to describe a cluster can be found at the **Implementation Notes of the `POST /clusters` API call**. All mentioned rules apply for this method as well.  After creating all new nodes, the runtime information of all nodes will be updated. The Roles of the already existing FPGA nodes are **not** reset during this method.  If errors occur during this method (e.g. 424 or 507), the original cluster will be unaffected.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cf_manager_rest_api_extend_cluster(body, username, password, cluster_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[ClustersBody] body: Mapping of Node-IDs to Images (required)
        :param str username: OpenStack username (required)
        :param str password: OpenStack password (required)
        :param int cluster_id: ID of a cluster (required)
        :param int dont_verify_memory: If 1, don't verify the DDR4 memory during setup
        :return: Cluster
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.cf_manager_rest_api_extend_cluster_with_http_info(body, username, password, cluster_id, **kwargs)  # noqa: E501
        else:
            (data) = self.cf_manager_rest_api_extend_cluster_with_http_info(body, username, password, cluster_id, **kwargs)  # noqa: E501
            return data

    def cf_manager_rest_api_extend_cluster_with_http_info(self, body, username, password, cluster_id, **kwargs):  # noqa: E501
        """Add nodes to an existing cluster  # noqa: E501

        This adds nodes to an existing cluster, as specified in the parameter `cluster_details`.  **Details** on how to describe a cluster can be found at the **Implementation Notes of the `POST /clusters` API call**. All mentioned rules apply for this method as well.  After creating all new nodes, the runtime information of all nodes will be updated. The Roles of the already existing FPGA nodes are **not** reset during this method.  If errors occur during this method (e.g. 424 or 507), the original cluster will be unaffected.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cf_manager_rest_api_extend_cluster_with_http_info(body, username, password, cluster_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[ClustersBody] body: Mapping of Node-IDs to Images (required)
        :param str username: OpenStack username (required)
        :param str password: OpenStack password (required)
        :param int cluster_id: ID of a cluster (required)
        :param int dont_verify_memory: If 1, don't verify the DDR4 memory during setup
        :return: Cluster
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'username', 'password', 'cluster_id', 'dont_verify_memory']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cf_manager_rest_api_extend_cluster" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `cf_manager_rest_api_extend_cluster`")  # noqa: E501
        # verify the required parameter 'username' is set
        if ('username' not in params or
                params['username'] is None):
            raise ValueError("Missing the required parameter `username` when calling `cf_manager_rest_api_extend_cluster`")  # noqa: E501
        # verify the required parameter 'password' is set
        if ('password' not in params or
                params['password'] is None):
            raise ValueError("Missing the required parameter `password` when calling `cf_manager_rest_api_extend_cluster`")  # noqa: E501
        # verify the required parameter 'cluster_id' is set
        if ('cluster_id' not in params or
                params['cluster_id'] is None):
            raise ValueError("Missing the required parameter `cluster_id` when calling `cf_manager_rest_api_extend_cluster`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cluster_id' in params:
            path_params['cluster_id'] = params['cluster_id']  # noqa: E501

        query_params = []
        if 'username' in params:
            query_params.append(('username', params['username']))  # noqa: E501
        if 'password' in params:
            query_params.append(('password', params['password']))  # noqa: E501
        if 'dont_verify_memory' in params:
            query_params.append(('dont_verify_memory', params['dont_verify_memory']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/clusters/{cluster_id}/extend', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Cluster',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def cf_manager_rest_api_get_cluster_single(self, username, password, cluster_id, **kwargs):  # noqa: E501
        """Get a cluster  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cf_manager_rest_api_get_cluster_single(username, password, cluster_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str username: OpenStack username (required)
        :param str password: OpenStack password (required)
        :param int cluster_id: ID of a cluster (required)
        :return: Cluster
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.cf_manager_rest_api_get_cluster_single_with_http_info(username, password, cluster_id, **kwargs)  # noqa: E501
        else:
            (data) = self.cf_manager_rest_api_get_cluster_single_with_http_info(username, password, cluster_id, **kwargs)  # noqa: E501
            return data

    def cf_manager_rest_api_get_cluster_single_with_http_info(self, username, password, cluster_id, **kwargs):  # noqa: E501
        """Get a cluster  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cf_manager_rest_api_get_cluster_single_with_http_info(username, password, cluster_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str username: OpenStack username (required)
        :param str password: OpenStack password (required)
        :param int cluster_id: ID of a cluster (required)
        :return: Cluster
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['username', 'password', 'cluster_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cf_manager_rest_api_get_cluster_single" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'username' is set
        if ('username' not in params or
                params['username'] is None):
            raise ValueError("Missing the required parameter `username` when calling `cf_manager_rest_api_get_cluster_single`")  # noqa: E501
        # verify the required parameter 'password' is set
        if ('password' not in params or
                params['password'] is None):
            raise ValueError("Missing the required parameter `password` when calling `cf_manager_rest_api_get_cluster_single`")  # noqa: E501
        # verify the required parameter 'cluster_id' is set
        if ('cluster_id' not in params or
                params['cluster_id'] is None):
            raise ValueError("Missing the required parameter `cluster_id` when calling `cf_manager_rest_api_get_cluster_single`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cluster_id' in params:
            path_params['cluster_id'] = params['cluster_id']  # noqa: E501

        query_params = []
        if 'username' in params:
            query_params.append(('username', params['username']))  # noqa: E501
        if 'password' in params:
            query_params.append(('password', params['password']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/clusters/{cluster_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Cluster',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def cf_manager_rest_api_get_clusters(self, username, password, **kwargs):  # noqa: E501
        """Get all clusters of a user  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cf_manager_rest_api_get_clusters(username, password, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str username: OpenStack username (required)
        :param str password: OpenStack password (required)
        :param int limit:
        :return: list[Cluster]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.cf_manager_rest_api_get_clusters_with_http_info(username, password, **kwargs)  # noqa: E501
        else:
            (data) = self.cf_manager_rest_api_get_clusters_with_http_info(username, password, **kwargs)  # noqa: E501
            return data

    def cf_manager_rest_api_get_clusters_with_http_info(self, username, password, **kwargs):  # noqa: E501
        """Get all clusters of a user  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cf_manager_rest_api_get_clusters_with_http_info(username, password, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str username: OpenStack username (required)
        :param str password: OpenStack password (required)
        :param int limit:
        :return: list[Cluster]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['username', 'password', 'limit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cf_manager_rest_api_get_clusters" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'username' is set
        if ('username' not in params or
                params['username'] is None):
            raise ValueError("Missing the required parameter `username` when calling `cf_manager_rest_api_get_clusters`")  # noqa: E501
        # verify the required parameter 'password' is set
        if ('password' not in params or
                params['password'] is None):
            raise ValueError("Missing the required parameter `password` when calling `cf_manager_rest_api_get_clusters`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'username' in params:
            query_params.append(('username', params['username']))  # noqa: E501
        if 'password' in params:
            query_params.append(('password', params['password']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/clusters', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Cluster]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def cf_manager_rest_api_post_clusters(self, body, username, password, **kwargs):  # noqa: E501
        """Request a cluster  # noqa: E501

        This triggers the configuration of all *FPGA nodes* of a cluster as specified in the parameter `cluster_details`.  The entry for an FPGA node must look like:  ```json {   \"node_id\": unique integer,   \"image_id\": \"XXX-XX-XXX\" } ```  The parameters `instance_id` and `node_ip` are set by the Resource Manager. The `node_id`s must be unique for the whole cluster (FPGAs and CPUs).   It is necessary to submit the information about the CPU nodes of a heterogeneous cluster to compile and distribute the *network routing configuration for the FPGAs correctly*.  Hence, the entry for a CPU must look like:  ```json {   \"node_id\": unique integer,   \"image_id\": \"NON_FPGA\",   \"node_ip\": \"10.12.47.11\" } ```  The setup of the CPU nodes must be done by the users themselves. The `node_ip` of a CPU must be in the OpenStack user subnetwork (i.e. `10.12.X.Y`). Currently, the maximum supported size of a cluster is 64 (FPGA + CPU nodes).   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cf_manager_rest_api_post_clusters(body, username, password, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[ClustersBody] body: Mapping of Node-IDs to Images (required)
        :param str username: OpenStack username (required)
        :param str password: OpenStack password (required)
        :param str project_name: Name of the OpenStack project the quota should be acounted to, if a user has multiple projects.
        :param int dont_verify_memory: If 1, don't verify the DDR4 memory during setup
        :return: Cluster
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.cf_manager_rest_api_post_clusters_with_http_info(body, username, password, **kwargs)  # noqa: E501
        else:
            (data) = self.cf_manager_rest_api_post_clusters_with_http_info(body, username, password, **kwargs)  # noqa: E501
            return data

    def cf_manager_rest_api_post_clusters_with_http_info(self, body, username, password, **kwargs):  # noqa: E501
        """Request a cluster  # noqa: E501

        This triggers the configuration of all *FPGA nodes* of a cluster as specified in the parameter `cluster_details`.  The entry for an FPGA node must look like:  ```json {   \"node_id\": unique integer,   \"image_id\": \"XXX-XX-XXX\" } ```  The parameters `instance_id` and `node_ip` are set by the Resource Manager. The `node_id`s must be unique for the whole cluster (FPGAs and CPUs).   It is necessary to submit the information about the CPU nodes of a heterogeneous cluster to compile and distribute the *network routing configuration for the FPGAs correctly*.  Hence, the entry for a CPU must look like:  ```json {   \"node_id\": unique integer,   \"image_id\": \"NON_FPGA\",   \"node_ip\": \"10.12.47.11\" } ```  The setup of the CPU nodes must be done by the users themselves. The `node_ip` of a CPU must be in the OpenStack user subnetwork (i.e. `10.12.X.Y`). Currently, the maximum supported size of a cluster is 64 (FPGA + CPU nodes).   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cf_manager_rest_api_post_clusters_with_http_info(body, username, password, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[ClustersBody] body: Mapping of Node-IDs to Images (required)
        :param str username: OpenStack username (required)
        :param str password: OpenStack password (required)
        :param str project_name: Name of the OpenStack project the quota should be acounted to, if a user has multiple projects.
        :param int dont_verify_memory: If 1, don't verify the DDR4 memory during setup
        :return: Cluster
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'username', 'password', 'project_name', 'dont_verify_memory']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cf_manager_rest_api_post_clusters" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `cf_manager_rest_api_post_clusters`")  # noqa: E501
        # verify the required parameter 'username' is set
        if ('username' not in params or
                params['username'] is None):
            raise ValueError("Missing the required parameter `username` when calling `cf_manager_rest_api_post_clusters`")  # noqa: E501
        # verify the required parameter 'password' is set
        if ('password' not in params or
                params['password'] is None):
            raise ValueError("Missing the required parameter `password` when calling `cf_manager_rest_api_post_clusters`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'username' in params:
            query_params.append(('username', params['username']))  # noqa: E501
        if 'password' in params:
            query_params.append(('password', params['password']))  # noqa: E501
        if 'project_name' in params:
            query_params.append(('project_name', params['project_name']))  # noqa: E501
        if 'dont_verify_memory' in params:
            query_params.append(('dont_verify_memory', params['dont_verify_memory']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/clusters', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Cluster',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def cf_manager_rest_api_reduce_cluster(self, body, username, password, cluster_id, **kwargs):  # noqa: E501
        """Remove nodes from an existing cluster  # noqa: E501

        This remove nodes the nodes in the `nodes_to_remove` list from an existing cluster.  The `nodes_to_remove` list must contain the `node_id`s of the nodes that should be removed.  After removing all specified nodes, the runtime information of all remaining nodes will be updated. The Roles of the remaining FPGA nodes are **not** reset during this method.  If the last remaining FPGA node is removed, the complete cluster will be deleted (like `DELETE /cluster/{cluster_id}`).  If errors occur during this method, the original/remaining cluster will be unaffected.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cf_manager_rest_api_reduce_cluster(body, username, password, cluster_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[int] body: List of Node-IDs that should be removed (required)
        :param str username: OpenStack username (required)
        :param str password: OpenStack password (required)
        :param int cluster_id: ID of a cluster (required)
        :return: Cluster
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.cf_manager_rest_api_reduce_cluster_with_http_info(body, username, password, cluster_id, **kwargs)  # noqa: E501
        else:
            (data) = self.cf_manager_rest_api_reduce_cluster_with_http_info(body, username, password, cluster_id, **kwargs)  # noqa: E501
            return data

    def cf_manager_rest_api_reduce_cluster_with_http_info(self, body, username, password, cluster_id, **kwargs):  # noqa: E501
        """Remove nodes from an existing cluster  # noqa: E501

        This remove nodes the nodes in the `nodes_to_remove` list from an existing cluster.  The `nodes_to_remove` list must contain the `node_id`s of the nodes that should be removed.  After removing all specified nodes, the runtime information of all remaining nodes will be updated. The Roles of the remaining FPGA nodes are **not** reset during this method.  If the last remaining FPGA node is removed, the complete cluster will be deleted (like `DELETE /cluster/{cluster_id}`).  If errors occur during this method, the original/remaining cluster will be unaffected.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cf_manager_rest_api_reduce_cluster_with_http_info(body, username, password, cluster_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[int] body: List of Node-IDs that should be removed (required)
        :param str username: OpenStack username (required)
        :param str password: OpenStack password (required)
        :param int cluster_id: ID of a cluster (required)
        :return: Cluster
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'username', 'password', 'cluster_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cf_manager_rest_api_reduce_cluster" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `cf_manager_rest_api_reduce_cluster`")  # noqa: E501
        # verify the required parameter 'username' is set
        if ('username' not in params or
                params['username'] is None):
            raise ValueError("Missing the required parameter `username` when calling `cf_manager_rest_api_reduce_cluster`")  # noqa: E501
        # verify the required parameter 'password' is set
        if ('password' not in params or
                params['password'] is None):
            raise ValueError("Missing the required parameter `password` when calling `cf_manager_rest_api_reduce_cluster`")  # noqa: E501
        # verify the required parameter 'cluster_id' is set
        if ('cluster_id' not in params or
                params['cluster_id'] is None):
            raise ValueError("Missing the required parameter `cluster_id` when calling `cf_manager_rest_api_reduce_cluster`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cluster_id' in params:
            path_params['cluster_id'] = params['cluster_id']  # noqa: E501

        query_params = []
        if 'username' in params:
            query_params.append(('username', params['username']))  # noqa: E501
        if 'password' in params:
            query_params.append(('password', params['password']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/clusters/{cluster_id}/reduce', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Cluster',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def cf_manager_rest_api_restart_cluster(self, username, password, cluster_id, **kwargs):  # noqa: E501
        """Restart all application on FPGAs in this cluster  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cf_manager_rest_api_restart_cluster(username, password, cluster_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str username: OpenStack username (required)
        :param str password: OpenStack password (required)
        :param int cluster_id: ID of a cluster (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.cf_manager_rest_api_restart_cluster_with_http_info(username, password, cluster_id, **kwargs)  # noqa: E501
        else:
            (data) = self.cf_manager_rest_api_restart_cluster_with_http_info(username, password, cluster_id, **kwargs)  # noqa: E501
            return data

    def cf_manager_rest_api_restart_cluster_with_http_info(self, username, password, cluster_id, **kwargs):  # noqa: E501
        """Restart all application on FPGAs in this cluster  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cf_manager_rest_api_restart_cluster_with_http_info(username, password, cluster_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str username: OpenStack username (required)
        :param str password: OpenStack password (required)
        :param int cluster_id: ID of a cluster (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['username', 'password', 'cluster_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cf_manager_rest_api_restart_cluster" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'username' is set
        if ('username' not in params or
                params['username'] is None):
            raise ValueError("Missing the required parameter `username` when calling `cf_manager_rest_api_restart_cluster`")  # noqa: E501
        # verify the required parameter 'password' is set
        if ('password' not in params or
                params['password'] is None):
            raise ValueError("Missing the required parameter `password` when calling `cf_manager_rest_api_restart_cluster`")  # noqa: E501
        # verify the required parameter 'cluster_id' is set
        if ('cluster_id' not in params or
                params['cluster_id'] is None):
            raise ValueError("Missing the required parameter `cluster_id` when calling `cf_manager_rest_api_restart_cluster`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cluster_id' in params:
            path_params['cluster_id'] = params['cluster_id']  # noqa: E501

        query_params = []
        if 'username' in params:
            query_params.append(('username', params['username']))  # noqa: E501
        if 'password' in params:
            query_params.append(('password', params['password']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/clusters/{cluster_id}/restart', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def cf_manager_rest_api_update_node_of_cluster(self, image_id, username, password, cluster_id, node_id, **kwargs):  # noqa: E501
        """Reconfigure one FPGA node of an existing cluster  # noqa: E501

        This method re-configures the given FPGA node in the given cluster. All settings remain the same and the runtime information of the cluster will be written to the updated instance again.  The Roles of the other FPGA nodes are **not** reset during this method.  If errors occur during this method, the other nodes of the cluster will be unaffected. **If this call fails with `507`** and the FPGA worked without any problems before, then the submitted image probably doesn't work (i.e. `507` doesn't imply a failure of the FPGA board).   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cf_manager_rest_api_update_node_of_cluster(image_id, username, password, cluster_id, node_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str image_id: (required)
        :param str username: OpenStack username (required)
        :param str password: OpenStack password (required)
        :param int cluster_id: ID of a cluster (required)
        :param int node_id: ID of a node within a cluster (required)
        :param int dont_verify_memory: If 1, don't verify the DDR4 memory during setup
        :return: Cluster
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.cf_manager_rest_api_update_node_of_cluster_with_http_info(image_id, username, password, cluster_id, node_id, **kwargs)  # noqa: E501
        else:
            (data) = self.cf_manager_rest_api_update_node_of_cluster_with_http_info(image_id, username, password, cluster_id, node_id, **kwargs)  # noqa: E501
            return data

    def cf_manager_rest_api_update_node_of_cluster_with_http_info(self, image_id, username, password, cluster_id, node_id, **kwargs):  # noqa: E501
        """Reconfigure one FPGA node of an existing cluster  # noqa: E501

        This method re-configures the given FPGA node in the given cluster. All settings remain the same and the runtime information of the cluster will be written to the updated instance again.  The Roles of the other FPGA nodes are **not** reset during this method.  If errors occur during this method, the other nodes of the cluster will be unaffected. **If this call fails with `507`** and the FPGA worked without any problems before, then the submitted image probably doesn't work (i.e. `507` doesn't imply a failure of the FPGA board).   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cf_manager_rest_api_update_node_of_cluster_with_http_info(image_id, username, password, cluster_id, node_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str image_id: (required)
        :param str username: OpenStack username (required)
        :param str password: OpenStack password (required)
        :param int cluster_id: ID of a cluster (required)
        :param int node_id: ID of a node within a cluster (required)
        :param int dont_verify_memory: If 1, don't verify the DDR4 memory during setup
        :return: Cluster
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['image_id', 'username', 'password', 'cluster_id', 'node_id', 'dont_verify_memory']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cf_manager_rest_api_update_node_of_cluster" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'image_id' is set
        if ('image_id' not in params or
                params['image_id'] is None):
            raise ValueError("Missing the required parameter `image_id` when calling `cf_manager_rest_api_update_node_of_cluster`")  # noqa: E501
        # verify the required parameter 'username' is set
        if ('username' not in params or
                params['username'] is None):
            raise ValueError("Missing the required parameter `username` when calling `cf_manager_rest_api_update_node_of_cluster`")  # noqa: E501
        # verify the required parameter 'password' is set
        if ('password' not in params or
                params['password'] is None):
            raise ValueError("Missing the required parameter `password` when calling `cf_manager_rest_api_update_node_of_cluster`")  # noqa: E501
        # verify the required parameter 'cluster_id' is set
        if ('cluster_id' not in params or
                params['cluster_id'] is None):
            raise ValueError("Missing the required parameter `cluster_id` when calling `cf_manager_rest_api_update_node_of_cluster`")  # noqa: E501
        # verify the required parameter 'node_id' is set
        if ('node_id' not in params or
                params['node_id'] is None):
            raise ValueError("Missing the required parameter `node_id` when calling `cf_manager_rest_api_update_node_of_cluster`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cluster_id' in params:
            path_params['cluster_id'] = params['cluster_id']  # noqa: E501
        if 'node_id' in params:
            path_params['node_id'] = params['node_id']  # noqa: E501

        query_params = []
        if 'username' in params:
            query_params.append(('username', params['username']))  # noqa: E501
        if 'password' in params:
            query_params.append(('password', params['password']))  # noqa: E501
        if 'dont_verify_memory' in params:
            query_params.append(('dont_verify_memory', params['dont_verify_memory']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'image_id' in params:
            form_params.append(('image_id', params['image_id']))  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/clusters/{cluster_id}/{node_id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Cluster',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    cloudFPGA Resource Manager API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.8
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.clusters_api import ClustersApi  # noqa: E501
from swagger_client.rest import ApiException


class TestClustersApi(unittest.TestCase):
    """ClustersApi unit test stubs"""

    def setUp(self):
        self.api = ClustersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_cf_manager_rest_api_delete_cluster(self):
        """Test case for cf_manager_rest_api_delete_cluster

        Delete a cluster  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_extend_cluster(self):
        """Test case for cf_manager_rest_api_extend_cluster

        Add nodes to an existing cluster  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_get_cluster_single(self):
        """Test case for cf_manager_rest_api_get_cluster_single

        Get a cluster  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_get_clusters(self):
        """Test case for cf_manager_rest_api_get_clusters

        Get all clusters of a user  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_post_clusters(self):
        """Test case for cf_manager_rest_api_post_clusters

        Request a cluster  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_reduce_cluster(self):
        """Test case for cf_manager_rest_api_reduce_cluster

        Remove nodes from an existing cluster  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_restart_cluster(self):
        """Test case for cf_manager_rest_api_restart_cluster

        Restart all application on FPGAs in this cluster  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_update_node_of_cluster(self):
        """Test case for cf_manager_rest_api_update_node_of_cluster

        Reconfigure one FPGA node of an existing cluster  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    cloudFPGA Resource Manager API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.8
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.mantle_architecture_api import MantleArchitectureApi  # noqa: E501
from swagger_client.rest import ApiException


class TestMantleArchitectureApi(unittest.TestCase):
    """MantleArchitectureApi unit test stubs"""

    def setUp(self):
        self.api = MantleArchitectureApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_cf_manager_rest_api_get_composable_logic_all_part(self):
        """Test case for cf_manager_rest_api_get_composable_logic_all_part

        Returns all composable logics of the given part that are `IN_USE`  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_get_composable_logic_all_prp(self):
        """Test case for cf_manager_rest_api_get_composable_logic_all_prp

        Returns all composable logics of the given prp-type that are `IN_USE`  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_get_composable_logic_all_shell_type(self):
        """Test case for cf_manager_rest_api_get_composable_logic_all_shell_type

        Returns all composable logics of the given shell-type that are `IN_USE`  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_get_composable_logic_dcp(self):
        """Test case for cf_manager_rest_api_get_composable_logic_dcp

        Get the dcp file of a composable logic  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_get_composable_logic_meta(self):
        """Test case for cf_manager_rest_api_get_composable_logic_meta

        Get the meta data of a composable logic  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# /*******************************************************************************
#  * Copyright 2016 -- 2022 IBM Corporation
#  *
#  * Licensed under the Apache License, Version 2.0 (the "License");
#  * you may not use this file except in compliance with the License.
#  * You may obtain a copy of the License at
#  *
#  *     http://www.apache.org/licenses/LICENSE-2.0
#  *
#  * Unless required by applicable law or agreed to in writing, software
#  * distributed under the License is distributed on an "AS IS" BASIS,
#  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  * See the License for the specific language governing permissions and
#  * limitations under the License.
# *******************************************************************************/

#  *                       cloudFPGA
#  *     Copyright IBM Research, All Rights Reserved
#  *    =============================================
#  *     Created: Jan. 2022
#  *     Authors: FAB, WEI, NGL, DID
#  *
#  *     Description:
#  *      The setup file used for buidling cfsp PyPi package.
#  *
#  *    License:
#  *     Apache Version 2.0


import setuptools, os
from shutil import copyfile

with open("README_pypi.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()
fh.close()


version_path = os.path.dirname(os.path.abspath(__file__))+"/cFSPlib/version.txt"
with open(version_path,"r") as fh:
    for line in fh:
        __version__ = line.rstrip("\n")
fh.close()


setuptools.setup(
    name="cfsp", 
    version=__version__,
    author="Dionysios Diamantopoulos",
    author_email="did@zurich.ibm.com",
    description="The cloudFPGA Support Package",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/cloudFPGA/cfsp",
    project_urls={
        "Bug Tracker": "https://github.com/cloudFPGA/cfsp/issues",
    },    
    packages=setuptools.find_packages(),
    setup_requires=['wheel'],
    install_requires=[
        "certifi",
        "charset-normalizer",
        "docopt",
        "idna",
        "prompt-toolkit",
        "Pygments",
        "PyInquirer",
        "regex",
        "requests",
        "six",
        "tqdm",
        "urllib3",
        "wcwidth",
    ],
    package_data={'':['cFSPlib']},   
    include_package_data=True,
    scripts=['cfsp'],
    classifiers=[
        "Intended Audience :: Developers",
        "License :: OSI Approved :: Apache Software License",
        "Programming Language :: Python :: 3",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
    python_requires='>=3.6',
)



# coding: utf-8

"""
    cloudFPGA Resource Manager API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.8
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.debug_api import DebugApi  # noqa: E501
from swagger_client.rest import ApiException


class TestDebugApi(unittest.TestCase):
    """DebugApi unit test stubs"""

    def setUp(self):
        self.api = DebugApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_cf_manager_rest_api_delete_debug_connection(self):
        """Test case for cf_manager_rest_api_delete_debug_connection

        Deletes an existing connection to the `hw_server` of this instance  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_get_all_debug_connections(self):
        """Test case for cf_manager_rest_api_get_all_debug_connections

        Requests a list of running `hw_server`s on all instances (admin only)  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_get_all_debug_connections_of_user(self):
        """Test case for cf_manager_rest_api_get_all_debug_connections_of_user

        Returns all open `hw_server` of a user  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_get_debug_connection(self):
        """Test case for cf_manager_rest_api_get_debug_connection

        Requests a connection to the `hw_server` of this instance  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_get_flight_recorder_cluster(self):
        """Test case for cf_manager_rest_api_get_flight_recorder_cluster

        Requests network runtime information of all instances  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_get_flight_recorder_instance(self):
        """Test case for cf_manager_rest_api_get_flight_recorder_instance

        Requests network runtime information  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    cloudFPGA Resource Manager API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.8
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.administration__admin_only_api import AdministrationAdminOnlyApi  # noqa: E501
from swagger_client.rest import ApiException


class TestAdministrationAdminOnlyApi(unittest.TestCase):
    """AdministrationAdminOnlyApi unit test stubs"""

    def setUp(self):
        self.api = AdministrationAdminOnlyApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_cf_manager_rest_api_admin_test_instance(self):
        """Test case for cf_manager_rest_api_admin_test_instance

        Test the instance **if not used**  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_admin_update_flash(self):
        """Test case for cf_manager_rest_api_admin_update_flash

        Update the flash of a resource **if not used**  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_delete_ippool(self):
        """Test case for cf_manager_rest_api_delete_ippool

        Remove a /24 subnet  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_get_all_composable_logic(self):
        """Test case for cf_manager_rest_api_get_all_composable_logic

        Get list of all composable logic  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_get_buildscripts_all(self):
        """Test case for cf_manager_rest_api_get_buildscripts_all

        Get all registered build script versions  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_get_ippool(self):
        """Test case for cf_manager_rest_api_get_ippool

        Get all ip addresses in the current pool  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_get_mantle_logic_all(self):
        """Test case for cf_manager_rest_api_get_mantle_logic_all

        Get all mantle logics  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_get_platform_logic_all(self):
        """Test case for cf_manager_rest_api_get_platform_logic_all

        Get all platform logics  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_get_single_buildscript(self):
        """Test case for cf_manager_rest_api_get_single_buildscript

        Get details of one registered build script  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_get_single_composable_logic(self):
        """Test case for cf_manager_rest_api_get_single_composable_logic

        Get details of one composable logic  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_post_buildscript(self):
        """Test case for cf_manager_rest_api_post_buildscript

        Register a new build script version  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_post_ippool(self):
        """Test case for cf_manager_rest_api_post_ippool

        Post a new `/24` ip pool (subnet)  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_post_mantle_logic(self):
        """Test case for cf_manager_rest_api_post_mantle_logic

        Upload a new dynamic platform logic  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_post_platform_logic(self):
        """Test case for cf_manager_rest_api_post_platform_logic

        Upload a new platform logic  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_put_buildscript(self):
        """Test case for cf_manager_rest_api_put_buildscript

        Update a registered build script  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_put_composable_logic_status(self):
        """Test case for cf_manager_rest_api_put_composable_logic_status

        Update status of a composable logic  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    cloudFPGA Resource Manager API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.8
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from swagger_client.api_client import ApiClient


class DebugApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def cf_manager_rest_api_delete_debug_connection(self, username, password, instance_id, **kwargs):  # noqa: E501
        """Deletes an existing connection to the `hw_server` of this instance  # noqa: E501

        This deletes the *connection to the* `hw_server`. This **does not imply** that the `hw_server` itself is stopped too. The `hw_server` is only stopped if there is no other open debug connection to the connected JTAG probe (some probes are connected to a JTAG chain).   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cf_manager_rest_api_delete_debug_connection(username, password, instance_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str username: OpenStack username (required)
        :param str password: OpenStack password (required)
        :param str instance_id: ROLE instance unique identifier (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.cf_manager_rest_api_delete_debug_connection_with_http_info(username, password, instance_id, **kwargs)  # noqa: E501
        else:
            (data) = self.cf_manager_rest_api_delete_debug_connection_with_http_info(username, password, instance_id, **kwargs)  # noqa: E501
            return data

    def cf_manager_rest_api_delete_debug_connection_with_http_info(self, username, password, instance_id, **kwargs):  # noqa: E501
        """Deletes an existing connection to the `hw_server` of this instance  # noqa: E501

        This deletes the *connection to the* `hw_server`. This **does not imply** that the `hw_server` itself is stopped too. The `hw_server` is only stopped if there is no other open debug connection to the connected JTAG probe (some probes are connected to a JTAG chain).   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cf_manager_rest_api_delete_debug_connection_with_http_info(username, password, instance_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str username: OpenStack username (required)
        :param str password: OpenStack password (required)
        :param str instance_id: ROLE instance unique identifier (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['username', 'password', 'instance_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cf_manager_rest_api_delete_debug_connection" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'username' is set
        if ('username' not in params or
                params['username'] is None):
            raise ValueError("Missing the required parameter `username` when calling `cf_manager_rest_api_delete_debug_connection`")  # noqa: E501
        # verify the required parameter 'password' is set
        if ('password' not in params or
                params['password'] is None):
            raise ValueError("Missing the required parameter `password` when calling `cf_manager_rest_api_delete_debug_connection`")  # noqa: E501
        # verify the required parameter 'instance_id' is set
        if ('instance_id' not in params or
                params['instance_id'] is None):
            raise ValueError("Missing the required parameter `instance_id` when calling `cf_manager_rest_api_delete_debug_connection`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'instance_id' in params:
            path_params['instance_id'] = params['instance_id']  # noqa: E501

        query_params = []
        if 'username' in params:
            query_params.append(('username', params['username']))  # noqa: E501
        if 'password' in params:
            query_params.append(('password', params['password']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/debug/ila_connection/{instance_id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def cf_manager_rest_api_get_all_debug_connections(self, username, password, **kwargs):  # noqa: E501
        """Requests a list of running `hw_server`s on all instances (admin only)  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cf_manager_rest_api_get_all_debug_connections(username, password, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str username: OpenStack username (required)
        :param str password: OpenStack password (required)
        :return: list[InlineResponse2003]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.cf_manager_rest_api_get_all_debug_connections_with_http_info(username, password, **kwargs)  # noqa: E501
        else:
            (data) = self.cf_manager_rest_api_get_all_debug_connections_with_http_info(username, password, **kwargs)  # noqa: E501
            return data

    def cf_manager_rest_api_get_all_debug_connections_with_http_info(self, username, password, **kwargs):  # noqa: E501
        """Requests a list of running `hw_server`s on all instances (admin only)  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cf_manager_rest_api_get_all_debug_connections_with_http_info(username, password, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str username: OpenStack username (required)
        :param str password: OpenStack password (required)
        :return: list[InlineResponse2003]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['username', 'password']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cf_manager_rest_api_get_all_debug_connections" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'username' is set
        if ('username' not in params or
                params['username'] is None):
            raise ValueError("Missing the required parameter `username` when calling `cf_manager_rest_api_get_all_debug_connections`")  # noqa: E501
        # verify the required parameter 'password' is set
        if ('password' not in params or
                params['password'] is None):
            raise ValueError("Missing the required parameter `password` when calling `cf_manager_rest_api_get_all_debug_connections`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'username' in params:
            query_params.append(('username', params['username']))  # noqa: E501
        if 'password' in params:
            query_params.append(('password', params['password']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/debug/open_ila_connections', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[InlineResponse2003]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def cf_manager_rest_api_get_all_debug_connections_of_user(self, username, password, **kwargs):  # noqa: E501
        """Returns all open `hw_server` of a user  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cf_manager_rest_api_get_all_debug_connections_of_user(username, password, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str username: OpenStack username (required)
        :param str password: OpenStack password (required)
        :return: list[InlineResponse2003]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.cf_manager_rest_api_get_all_debug_connections_of_user_with_http_info(username, password, **kwargs)  # noqa: E501
        else:
            (data) = self.cf_manager_rest_api_get_all_debug_connections_of_user_with_http_info(username, password, **kwargs)  # noqa: E501
            return data

    def cf_manager_rest_api_get_all_debug_connections_of_user_with_http_info(self, username, password, **kwargs):  # noqa: E501
        """Returns all open `hw_server` of a user  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cf_manager_rest_api_get_all_debug_connections_of_user_with_http_info(username, password, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str username: OpenStack username (required)
        :param str password: OpenStack password (required)
        :return: list[InlineResponse2003]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['username', 'password']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cf_manager_rest_api_get_all_debug_connections_of_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'username' is set
        if ('username' not in params or
                params['username'] is None):
            raise ValueError("Missing the required parameter `username` when calling `cf_manager_rest_api_get_all_debug_connections_of_user`")  # noqa: E501
        # verify the required parameter 'password' is set
        if ('password' not in params or
                params['password'] is None):
            raise ValueError("Missing the required parameter `password` when calling `cf_manager_rest_api_get_all_debug_connections_of_user`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'username' in params:
            query_params.append(('username', params['username']))  # noqa: E501
        if 'password' in params:
            query_params.append(('password', params['password']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/debug/ila_connections', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[InlineResponse2003]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def cf_manager_rest_api_get_debug_connection(self, username, password, instance_id, **kwargs):  # noqa: E501
        """Requests a connection to the `hw_server` of this instance  # noqa: E501

        This returns an IP-address and a TCP port to enter into the *remote debugging dialog* in `vivado_lab`. **Only the IP-address that issues this request will be allowed to connect (or the specified IP address).**  If there is already an open debug connection to the specified instance, the existing data will be returned. That means, to debug the same instance on a different client, the connection must be deleted first.  Due to ongoing Hardware Development it is possible that there are more than one FPGA visible in the debug connection (some FPGAs share a JTAG probe via a JTAG chain). **You are only allowed to interact with the device that is stated in the `device` value in the response from the server.** (The Resource Manager assures that the devices in a JTAG chain are only given to members of the same project, so if you interact with other devices, you will disturb your direct colleges).   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cf_manager_rest_api_get_debug_connection(username, password, instance_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str username: OpenStack username (required)
        :param str password: OpenStack password (required)
        :param str instance_id: ROLE instance unique identifier (required)
        :param str ip_address: IPv4 address of the Debuging client if different from requesting client (only this addres will be allowed to connect).
        :return: InlineResponse2002
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.cf_manager_rest_api_get_debug_connection_with_http_info(username, password, instance_id, **kwargs)  # noqa: E501
        else:
            (data) = self.cf_manager_rest_api_get_debug_connection_with_http_info(username, password, instance_id, **kwargs)  # noqa: E501
            return data

    def cf_manager_rest_api_get_debug_connection_with_http_info(self, username, password, instance_id, **kwargs):  # noqa: E501
        """Requests a connection to the `hw_server` of this instance  # noqa: E501

        This returns an IP-address and a TCP port to enter into the *remote debugging dialog* in `vivado_lab`. **Only the IP-address that issues this request will be allowed to connect (or the specified IP address).**  If there is already an open debug connection to the specified instance, the existing data will be returned. That means, to debug the same instance on a different client, the connection must be deleted first.  Due to ongoing Hardware Development it is possible that there are more than one FPGA visible in the debug connection (some FPGAs share a JTAG probe via a JTAG chain). **You are only allowed to interact with the device that is stated in the `device` value in the response from the server.** (The Resource Manager assures that the devices in a JTAG chain are only given to members of the same project, so if you interact with other devices, you will disturb your direct colleges).   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cf_manager_rest_api_get_debug_connection_with_http_info(username, password, instance_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str username: OpenStack username (required)
        :param str password: OpenStack password (required)
        :param str instance_id: ROLE instance unique identifier (required)
        :param str ip_address: IPv4 address of the Debuging client if different from requesting client (only this addres will be allowed to connect).
        :return: InlineResponse2002
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['username', 'password', 'instance_id', 'ip_address']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cf_manager_rest_api_get_debug_connection" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'username' is set
        if ('username' not in params or
                params['username'] is None):
            raise ValueError("Missing the required parameter `username` when calling `cf_manager_rest_api_get_debug_connection`")  # noqa: E501
        # verify the required parameter 'password' is set
        if ('password' not in params or
                params['password'] is None):
            raise ValueError("Missing the required parameter `password` when calling `cf_manager_rest_api_get_debug_connection`")  # noqa: E501
        # verify the required parameter 'instance_id' is set
        if ('instance_id' not in params or
                params['instance_id'] is None):
            raise ValueError("Missing the required parameter `instance_id` when calling `cf_manager_rest_api_get_debug_connection`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'instance_id' in params:
            path_params['instance_id'] = params['instance_id']  # noqa: E501

        query_params = []
        if 'username' in params:
            query_params.append(('username', params['username']))  # noqa: E501
        if 'password' in params:
            query_params.append(('password', params['password']))  # noqa: E501
        if 'ip_address' in params:
            query_params.append(('ip_address', params['ip_address']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/debug/ila_connection/{instance_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2002',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def cf_manager_rest_api_get_flight_recorder_cluster(self, username, password, cluster_id, **kwargs):  # noqa: E501
        """Requests network runtime information of all instances  # noqa: E501

        Requests and returns the status information of the Network Routing Core of all instances in this cluster `Attention:` There may be a delay of a few seconds until the counters are updated after the packets were processed.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cf_manager_rest_api_get_flight_recorder_cluster(username, password, cluster_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str username: OpenStack username (required)
        :param str password: OpenStack password (required)
        :param int cluster_id: ID of a cluster (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.cf_manager_rest_api_get_flight_recorder_cluster_with_http_info(username, password, cluster_id, **kwargs)  # noqa: E501
        else:
            (data) = self.cf_manager_rest_api_get_flight_recorder_cluster_with_http_info(username, password, cluster_id, **kwargs)  # noqa: E501
            return data

    def cf_manager_rest_api_get_flight_recorder_cluster_with_http_info(self, username, password, cluster_id, **kwargs):  # noqa: E501
        """Requests network runtime information of all instances  # noqa: E501

        Requests and returns the status information of the Network Routing Core of all instances in this cluster `Attention:` There may be a delay of a few seconds until the counters are updated after the packets were processed.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cf_manager_rest_api_get_flight_recorder_cluster_with_http_info(username, password, cluster_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str username: OpenStack username (required)
        :param str password: OpenStack password (required)
        :param int cluster_id: ID of a cluster (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['username', 'password', 'cluster_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cf_manager_rest_api_get_flight_recorder_cluster" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'username' is set
        if ('username' not in params or
                params['username'] is None):
            raise ValueError("Missing the required parameter `username` when calling `cf_manager_rest_api_get_flight_recorder_cluster`")  # noqa: E501
        # verify the required parameter 'password' is set
        if ('password' not in params or
                params['password'] is None):
            raise ValueError("Missing the required parameter `password` when calling `cf_manager_rest_api_get_flight_recorder_cluster`")  # noqa: E501
        # verify the required parameter 'cluster_id' is set
        if ('cluster_id' not in params or
                params['cluster_id'] is None):
            raise ValueError("Missing the required parameter `cluster_id` when calling `cf_manager_rest_api_get_flight_recorder_cluster`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cluster_id' in params:
            path_params['cluster_id'] = params['cluster_id']  # noqa: E501

        query_params = []
        if 'username' in params:
            query_params.append(('username', params['username']))  # noqa: E501
        if 'password' in params:
            query_params.append(('password', params['password']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/clusters/{cluster_id}/flight_recorder_data', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def cf_manager_rest_api_get_flight_recorder_instance(self, username, password, instance_id, **kwargs):  # noqa: E501
        """Requests network runtime information  # noqa: E501

        Requests and returns the status information of the Network Routing Core of this FPGA instance `Attention:` There may be a delay of a few seconds until the counters are updated after the packets were processed.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cf_manager_rest_api_get_flight_recorder_instance(username, password, instance_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str username: OpenStack username (required)
        :param str password: OpenStack password (required)
        :param str instance_id: ROLE instance unique identifier (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.cf_manager_rest_api_get_flight_recorder_instance_with_http_info(username, password, instance_id, **kwargs)  # noqa: E501
        else:
            (data) = self.cf_manager_rest_api_get_flight_recorder_instance_with_http_info(username, password, instance_id, **kwargs)  # noqa: E501
            return data

    def cf_manager_rest_api_get_flight_recorder_instance_with_http_info(self, username, password, instance_id, **kwargs):  # noqa: E501
        """Requests network runtime information  # noqa: E501

        Requests and returns the status information of the Network Routing Core of this FPGA instance `Attention:` There may be a delay of a few seconds until the counters are updated after the packets were processed.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cf_manager_rest_api_get_flight_recorder_instance_with_http_info(username, password, instance_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str username: OpenStack username (required)
        :param str password: OpenStack password (required)
        :param str instance_id: ROLE instance unique identifier (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['username', 'password', 'instance_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cf_manager_rest_api_get_flight_recorder_instance" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'username' is set
        if ('username' not in params or
                params['username'] is None):
            raise ValueError("Missing the required parameter `username` when calling `cf_manager_rest_api_get_flight_recorder_instance`")  # noqa: E501
        # verify the required parameter 'password' is set
        if ('password' not in params or
                params['password'] is None):
            raise ValueError("Missing the required parameter `password` when calling `cf_manager_rest_api_get_flight_recorder_instance`")  # noqa: E501
        # verify the required parameter 'instance_id' is set
        if ('instance_id' not in params or
                params['instance_id'] is None):
            raise ValueError("Missing the required parameter `instance_id` when calling `cf_manager_rest_api_get_flight_recorder_instance`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'instance_id' in params:
            path_params['instance_id'] = params['instance_id']  # noqa: E501

        query_params = []
        if 'username' in params:
            query_params.append(('username', params['username']))  # noqa: E501
        if 'password' in params:
            query_params.append(('password', params['password']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/instances/{instance_id}/flight_recorder_data', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# *****************************************************************************
# *                            cloudFPGA
# *                Copyright 2016 -- 2022 IBM Corporation
# * Licensed under the Apache License, Version 2.0 (the "License");
# * you may not use this file except in compliance with the License.
# * You may obtain a copy of the License at
# *
# *     http://www.apache.org/licenses/LICENSE-2.0
# *
# * Unless required by applicable law or agreed to in writing, software
# * distributed under the License is distributed on an "AS IS" BASIS,
# * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# * See the License for the specific language governing permissions and
# * limitations under the License.
# *----------------------------------------------------------------------------

"""
Usage:
    cfsp user (load | show) [-c CFGFILE]
Commands:
    load         Load credentials from a file
    show         Show the credentials of a file
Options:
    -c --config CFGFILE  Specify the configfile that rsnapshot should use 
                         [default: ./user.json]    
"""
from docopt import docopt
import json
import cfsp_globals
import sys
import os

####################################################################################################
# User functions
####################################################################################################

class cFuser:
    """A user in the cloudFPGA world"""

    def __init__(self, CFGFILE):
        username, password, project = load_user_credentials(CFGFILE)
        self.project = project
        self.username = username
        self.password = password
        self.CFGFILE = CFGFILE


    def get_auth_string(self, with_project=False):
        if with_project:
            s = "username={0}&password={1}&project_name={2}".format(self.username, self.password, self.project)
            return requests.utils.requote_uri(s)
        else:
            s = "username={0}&password={1}".format(self.username, self.password)
            return requests.utils.requote_uri(s)

    def set_project(self, new_project):
        """
        This method should be used if the cloudFPGA quota name that should be used for this handle is different from the
        default or credentials file
        :param new_project:
        :return: nothing
        """
        self.project = new_project

    def print_credentials(self):
        print("File     : " + self.CFGFILE)
        print("User     : " + self.username)
        print("Password : " + self.password)
        print("Project  : " + self.project)



def main(args):
    if (len(args['<args>']) != 1):
        print("ERROR: invalid arguments provided in 'cfsp user' command. Aborting...")
        exit(print(__doc__))
    
    if args['<args>'][0] == 'load':
        if (len(args['<args>']) == 1):
            user=cFuser(args['--config'])
        else:
            print("ERROR: invalid arguments provided in cfsp user load. Aborting...")
            sys.exit(-1)
        if args['--username'] != 'username_example':
            cfsp_globals.__cfsp_username__ = user.username = args['--username']
        else:
            cfsp_globals.__cfsp_username__ = user.username
        if args['--password'] != 'password_example':
            cfsp_globals.__cfsp_password__ = user.password = args['--password']        
        else:
            cfsp_globals.__cfsp_password__ = user.password
        if args['--project'] != 'project_example':
            cfsp_globals.__cfsp_project__ = user.project = args['--project']        
        else:
            cfsp_globals.__cfsp_project__ = user.project
        write_user_credentials(args['--config'])
    elif args['<args>'][0] == 'show':
        if (len(args['<args>']) == 1):
            print_user_credentials_from_file(args['--config'])
        else:
            print("ERROR: invalid arguments provided in cfsp user show. Aborting...")
            sys.exit(-1)
    else:
        exit(print("ERROR: invalid command provided in cfsp user. Type 'cfsp help user' to get a list of supported commands. Aborting..."))
        
def load_user_credentials(json_file):
    """returns username, password, and project from a JSON file"""
    username = ""
    password = ""
    project = ""

    try:
        if os.path.exists(json_file):
            with open(json_file, 'r') as infile:
                data = json.load(infile)
            username = data['credentials']['username']
            password = data['credentials']['password']
            if 'project' in data:
                project = data['project']
            else:
                project = cfsp_globals.__openstack_user_template__['project']
        else:
            print("INFO: Creating new user credentials file : {}\n".format(os.path.abspath(json_file)))
            write_user_credentials(json_file)
    except Exception as e:
        exit(print(e))
    return username, password, project           


def write_user_credentials(json_file):
    """writes credentials to a JSON file"""
    __cfsp_template__ = {}
    __cfsp_template__['credentials'] = {}
    __cfsp_template__['credentials']['username'] = cfsp_globals.__cfsp_username__
    __cfsp_template__['credentials']['password'] = cfsp_globals.__cfsp_password__
    __cfsp_template__['project'] = cfsp_globals.__cfsp_project__    
    try:
        with open(json_file, 'w') as outfile:
            json.dump(__cfsp_template__, outfile)
    except Exception as e:
        print(e)
        
def print_user_credentials_from_file(json_file):
    try:
        with open(json_file, 'r') as infile:
            data = json.load(infile)
        username = data['credentials']['username']
        password = data['credentials']['password']
        if 'project' in data:
            project = data['project']
        else:
            project = cfsp_globals.__openstack_user_template__['project']
        print("User     : " + username)
        print("Password : " + password)
        print("Project  : " + project)
        return 0
    except Exception as e:
        print(e)
        print("No credentials found \n")
        sys.exit(1)
        
        
        
        
if __name__ == '__main__':
    main()        



# coding: utf-8

"""
    cloudFPGA Resource Manager API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.8
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from swagger_client.api_client import ApiClient


class ImagesApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def cf_manager_rest_api_delete_image(self, username, password, image_id, **kwargs):  # noqa: E501
        """Delete an image  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cf_manager_rest_api_delete_image(username, password, image_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str username: OpenStack username (required)
        :param str password: OpenStack password (required)
        :param str image_id: Image unique identifier (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.cf_manager_rest_api_delete_image_with_http_info(username, password, image_id, **kwargs)  # noqa: E501
        else:
            (data) = self.cf_manager_rest_api_delete_image_with_http_info(username, password, image_id, **kwargs)  # noqa: E501
            return data

    def cf_manager_rest_api_delete_image_with_http_info(self, username, password, image_id, **kwargs):  # noqa: E501
        """Delete an image  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cf_manager_rest_api_delete_image_with_http_info(username, password, image_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str username: OpenStack username (required)
        :param str password: OpenStack password (required)
        :param str image_id: Image unique identifier (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['username', 'password', 'image_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cf_manager_rest_api_delete_image" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'username' is set
        if ('username' not in params or
                params['username'] is None):
            raise ValueError("Missing the required parameter `username` when calling `cf_manager_rest_api_delete_image`")  # noqa: E501
        # verify the required parameter 'password' is set
        if ('password' not in params or
                params['password'] is None):
            raise ValueError("Missing the required parameter `password` when calling `cf_manager_rest_api_delete_image`")  # noqa: E501
        # verify the required parameter 'image_id' is set
        if ('image_id' not in params or
                params['image_id'] is None):
            raise ValueError("Missing the required parameter `image_id` when calling `cf_manager_rest_api_delete_image`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'image_id' in params:
            path_params['image_id'] = params['image_id']  # noqa: E501

        query_params = []
        if 'username' in params:
            query_params.append(('username', params['username']))  # noqa: E501
        if 'password' in params:
            query_params.append(('password', params['password']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/images/{image_id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def cf_manager_rest_api_get_image_single(self, username, password, image_id, **kwargs):  # noqa: E501
        """Get an image  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cf_manager_rest_api_get_image_single(username, password, image_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str username: OpenStack username (required)
        :param str password: OpenStack password (required)
        :param str image_id: Image unique identifier (required)
        :return: Image
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.cf_manager_rest_api_get_image_single_with_http_info(username, password, image_id, **kwargs)  # noqa: E501
        else:
            (data) = self.cf_manager_rest_api_get_image_single_with_http_info(username, password, image_id, **kwargs)  # noqa: E501
            return data

    def cf_manager_rest_api_get_image_single_with_http_info(self, username, password, image_id, **kwargs):  # noqa: E501
        """Get an image  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cf_manager_rest_api_get_image_single_with_http_info(username, password, image_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str username: OpenStack username (required)
        :param str password: OpenStack password (required)
        :param str image_id: Image unique identifier (required)
        :return: Image
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['username', 'password', 'image_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cf_manager_rest_api_get_image_single" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'username' is set
        if ('username' not in params or
                params['username'] is None):
            raise ValueError("Missing the required parameter `username` when calling `cf_manager_rest_api_get_image_single`")  # noqa: E501
        # verify the required parameter 'password' is set
        if ('password' not in params or
                params['password'] is None):
            raise ValueError("Missing the required parameter `password` when calling `cf_manager_rest_api_get_image_single`")  # noqa: E501
        # verify the required parameter 'image_id' is set
        if ('image_id' not in params or
                params['image_id'] is None):
            raise ValueError("Missing the required parameter `image_id` when calling `cf_manager_rest_api_get_image_single`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'image_id' in params:
            path_params['image_id'] = params['image_id']  # noqa: E501

        query_params = []
        if 'username' in params:
            query_params.append(('username', params['username']))  # noqa: E501
        if 'password' in params:
            query_params.append(('password', params['password']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/images/{image_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Image',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def cf_manager_rest_api_get_images(self, username, password, **kwargs):  # noqa: E501
        """Get all images of a user  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cf_manager_rest_api_get_images(username, password, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str username: OpenStack username (required)
        :param str password: OpenStack password (required)
        :param int limit:
        :return: list[Image]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.cf_manager_rest_api_get_images_with_http_info(username, password, **kwargs)  # noqa: E501
        else:
            (data) = self.cf_manager_rest_api_get_images_with_http_info(username, password, **kwargs)  # noqa: E501
            return data

    def cf_manager_rest_api_get_images_with_http_info(self, username, password, **kwargs):  # noqa: E501
        """Get all images of a user  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cf_manager_rest_api_get_images_with_http_info(username, password, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str username: OpenStack username (required)
        :param str password: OpenStack password (required)
        :param int limit:
        :return: list[Image]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['username', 'password', 'limit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cf_manager_rest_api_get_images" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'username' is set
        if ('username' not in params or
                params['username'] is None):
            raise ValueError("Missing the required parameter `username` when calling `cf_manager_rest_api_get_images`")  # noqa: E501
        # verify the required parameter 'password' is set
        if ('password' not in params or
                params['password'] is None):
            raise ValueError("Missing the required parameter `password` when calling `cf_manager_rest_api_get_images`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'username' in params:
            query_params.append(('username', params['username']))  # noqa: E501
        if 'password' in params:
            query_params.append(('password', params['password']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/images', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Image]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def cf_manager_rest_api_post_app_logic(self, image_details, image_file, sig_file, pr_verify_rpt, username, password, **kwargs):  # noqa: E501
        """Upload an image of type `app logic`  # noqa: E501

        This uploads an new image (aka FPGA **bin**file). **This method is for the app logic in case of partial reconfiguration building on platform logics**. The `id` of the uploaded Image can then be used to create *Instances* or *Clusters*. It **must** contain the corresponding .sig file that was produced by the build. The resulting image can be viewed and deleted like other images.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cf_manager_rest_api_post_app_logic(image_details, image_file, sig_file, pr_verify_rpt, username, password, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str image_details: (required)
        :param str image_file: (required)
        :param str sig_file: (required)
        :param str pr_verify_rpt: (required)
        :param str username: OpenStack username (required)
        :param str password: OpenStack password (required)
        :return: Image
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.cf_manager_rest_api_post_app_logic_with_http_info(image_details, image_file, sig_file, pr_verify_rpt, username, password, **kwargs)  # noqa: E501
        else:
            (data) = self.cf_manager_rest_api_post_app_logic_with_http_info(image_details, image_file, sig_file, pr_verify_rpt, username, password, **kwargs)  # noqa: E501
            return data

    def cf_manager_rest_api_post_app_logic_with_http_info(self, image_details, image_file, sig_file, pr_verify_rpt, username, password, **kwargs):  # noqa: E501
        """Upload an image of type `app logic`  # noqa: E501

        This uploads an new image (aka FPGA **bin**file). **This method is for the app logic in case of partial reconfiguration building on platform logics**. The `id` of the uploaded Image can then be used to create *Instances* or *Clusters*. It **must** contain the corresponding .sig file that was produced by the build. The resulting image can be viewed and deleted like other images.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cf_manager_rest_api_post_app_logic_with_http_info(image_details, image_file, sig_file, pr_verify_rpt, username, password, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str image_details: (required)
        :param str image_file: (required)
        :param str sig_file: (required)
        :param str pr_verify_rpt: (required)
        :param str username: OpenStack username (required)
        :param str password: OpenStack password (required)
        :return: Image
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['image_details', 'image_file', 'sig_file', 'pr_verify_rpt', 'username', 'password']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cf_manager_rest_api_post_app_logic" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'image_details' is set
        if ('image_details' not in params or
                params['image_details'] is None):
            raise ValueError("Missing the required parameter `image_details` when calling `cf_manager_rest_api_post_app_logic`")  # noqa: E501
        # verify the required parameter 'image_file' is set
        if ('image_file' not in params or
                params['image_file'] is None):
            raise ValueError("Missing the required parameter `image_file` when calling `cf_manager_rest_api_post_app_logic`")  # noqa: E501
        # verify the required parameter 'sig_file' is set
        if ('sig_file' not in params or
                params['sig_file'] is None):
            raise ValueError("Missing the required parameter `sig_file` when calling `cf_manager_rest_api_post_app_logic`")  # noqa: E501
        # verify the required parameter 'pr_verify_rpt' is set
        if ('pr_verify_rpt' not in params or
                params['pr_verify_rpt'] is None):
            raise ValueError("Missing the required parameter `pr_verify_rpt` when calling `cf_manager_rest_api_post_app_logic`")  # noqa: E501
        # verify the required parameter 'username' is set
        if ('username' not in params or
                params['username'] is None):
            raise ValueError("Missing the required parameter `username` when calling `cf_manager_rest_api_post_app_logic`")  # noqa: E501
        # verify the required parameter 'password' is set
        if ('password' not in params or
                params['password'] is None):
            raise ValueError("Missing the required parameter `password` when calling `cf_manager_rest_api_post_app_logic`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'username' in params:
            query_params.append(('username', params['username']))  # noqa: E501
        if 'password' in params:
            query_params.append(('password', params['password']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'image_details' in params:
            form_params.append(('image_details', params['image_details']))  # noqa: E501
        if 'image_file' in params:
            local_var_files['image_file'] = params['image_file']  # noqa: E501
        if 'sig_file' in params:
            local_var_files['sig_file'] = params['sig_file']  # noqa: E501
        if 'pr_verify_rpt' in params:
            local_var_files['pr_verify_rpt'] = params['pr_verify_rpt']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/images/app_logic', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Image',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def cf_manager_rest_api_post_images(self, image_details, image_file, pr_verify_rpt, username, password, **kwargs):  # noqa: E501
        """Upload an image  # noqa: E501

        This uploads an new Image (aka FPGA bitfile). The `id` of the uploaded Image can then be used to create *Instances* or *Clusters*.  If the bitfile **is not a partial bitfile**, the *image_detail* **property `breed` must be `\"SHELL\"`**. The *image_detail* property `shell_type` is only relevant for the partial reconfiguration flow, but cannot be empty (e.g. enter `\"NO_PR\"`).   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cf_manager_rest_api_post_images(image_details, image_file, pr_verify_rpt, username, password, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str image_details: (required)
        :param str image_file: (required)
        :param str pr_verify_rpt: (required)
        :param str username: OpenStack username (required)
        :param str password: OpenStack password (required)
        :return: Image
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.cf_manager_rest_api_post_images_with_http_info(image_details, image_file, pr_verify_rpt, username, password, **kwargs)  # noqa: E501
        else:
            (data) = self.cf_manager_rest_api_post_images_with_http_info(image_details, image_file, pr_verify_rpt, username, password, **kwargs)  # noqa: E501
            return data

    def cf_manager_rest_api_post_images_with_http_info(self, image_details, image_file, pr_verify_rpt, username, password, **kwargs):  # noqa: E501
        """Upload an image  # noqa: E501

        This uploads an new Image (aka FPGA bitfile). The `id` of the uploaded Image can then be used to create *Instances* or *Clusters*.  If the bitfile **is not a partial bitfile**, the *image_detail* **property `breed` must be `\"SHELL\"`**. The *image_detail* property `shell_type` is only relevant for the partial reconfiguration flow, but cannot be empty (e.g. enter `\"NO_PR\"`).   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cf_manager_rest_api_post_images_with_http_info(image_details, image_file, pr_verify_rpt, username, password, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str image_details: (required)
        :param str image_file: (required)
        :param str pr_verify_rpt: (required)
        :param str username: OpenStack username (required)
        :param str password: OpenStack password (required)
        :return: Image
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['image_details', 'image_file', 'pr_verify_rpt', 'username', 'password']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cf_manager_rest_api_post_images" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'image_details' is set
        if ('image_details' not in params or
                params['image_details'] is None):
            raise ValueError("Missing the required parameter `image_details` when calling `cf_manager_rest_api_post_images`")  # noqa: E501
        # verify the required parameter 'image_file' is set
        if ('image_file' not in params or
                params['image_file'] is None):
            raise ValueError("Missing the required parameter `image_file` when calling `cf_manager_rest_api_post_images`")  # noqa: E501
        # verify the required parameter 'pr_verify_rpt' is set
        if ('pr_verify_rpt' not in params or
                params['pr_verify_rpt'] is None):
            raise ValueError("Missing the required parameter `pr_verify_rpt` when calling `cf_manager_rest_api_post_images`")  # noqa: E501
        # verify the required parameter 'username' is set
        if ('username' not in params or
                params['username'] is None):
            raise ValueError("Missing the required parameter `username` when calling `cf_manager_rest_api_post_images`")  # noqa: E501
        # verify the required parameter 'password' is set
        if ('password' not in params or
                params['password'] is None):
            raise ValueError("Missing the required parameter `password` when calling `cf_manager_rest_api_post_images`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'username' in params:
            query_params.append(('username', params['username']))  # noqa: E501
        if 'password' in params:
            query_params.append(('password', params['password']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'image_details' in params:
            form_params.append(('image_details', params['image_details']))  # noqa: E501
        if 'image_file' in params:
            local_var_files['image_file'] = params['image_file']  # noqa: E501
        if 'pr_verify_rpt' in params:
            local_var_files['pr_verify_rpt'] = params['pr_verify_rpt']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/images', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Image',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# *****************************************************************************
# *                            cloudFPGA
# *                Copyright 2016 -- 2022 IBM Corporation
# * Licensed under the Apache License, Version 2.0 (the "License");
# * you may not use this file except in compliance with the License.
# * You may obtain a copy of the License at
# *
# *     http://www.apache.org/licenses/LICENSE-2.0
# *
# * Unless required by applicable law or agreed to in writing, software
# * distributed under the License is distributed on an "AS IS" BASIS,
# * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# * See the License for the specific language governing permissions and
# * limitations under the License.
# *----------------------------------------------------------------------------

####################################################################################################
# Global Constants
####################################################################################################

__openstack_user_template__ = {}
__openstack_user_template__['credentials'] = {}
__openstack_user_template__['credentials']['username'] = "your user name"
__openstack_user_template__['credentials']['password'] = "your user password"
__openstack_user_template__['project'] = "default"

__cf_manager_url__ = "10.12.0.132:8080"
__NON_FPGA_IDENTIFIER__ = "NON_FPGA"

__cfsp_username__ = 'gobal_username_example'
__cfsp_password__ = 'gobal_password_example'
__cfsp_project__  = 'default'

__POST_CLUSTER_TIMEOUT__   = 130
__GET_CLUSTER_TIMEOUT__    = 5
__DELETE_CLUSTER_TIMEOUT__ = 20

__GET_INSTANCE_TIMEOUT__    = 5
__DELETE_INSTANCE_TIMEOUT__ = 20



# coding: utf-8

# flake8: noqa

"""
    cloudFPGA Resource Manager API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.8
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import apis into sdk package
from swagger_client.api.administration__admin_only_api import AdministrationAdminOnlyApi
from swagger_client.api.clusters_api import ClustersApi
from swagger_client.api.debug_api import DebugApi
from swagger_client.api.images_api import ImagesApi
from swagger_client.api.instances_api import InstancesApi
from swagger_client.api.mantle_architecture_api import MantleArchitectureApi
from swagger_client.api.projects_api import ProjectsApi
from swagger_client.api.resources__admin_only_api import ResourcesAdminOnlyApi
# import ApiClient
from swagger_client.api_client import ApiClient
from swagger_client.configuration import Configuration
# import models into sdk package
from swagger_client.models.administration_mantle_logic_body import AdministrationMantleLogicBody
from swagger_client.models.administration_platform_logic_body import AdministrationPlatformLogicBody
from swagger_client.models.build_script import BuildScript
from swagger_client.models.cluster import Cluster
from swagger_client.models.cluster_id_node_id_body import ClusterIdNodeIdBody
from swagger_client.models.clusters_body import ClustersBody
from swagger_client.models.image import Image
from swagger_client.models.images_app_logic_body import ImagesAppLogicBody
from swagger_client.models.images_body import ImagesBody
from swagger_client.models.inline_response200 import InlineResponse200
from swagger_client.models.inline_response2001 import InlineResponse2001
from swagger_client.models.inline_response2002 import InlineResponse2002
from swagger_client.models.inline_response2003 import InlineResponse2003
from swagger_client.models.inline_response2004 import InlineResponse2004
from swagger_client.models.inline_response2005 import InlineResponse2005
from swagger_client.models.instance import Instance
from swagger_client.models.instance_id_api_gateway_body import InstanceIdApiGatewayBody
from swagger_client.models.instance_id_runlevel_body import InstanceIdRunlevelBody
from swagger_client.models.instances_body import InstancesBody
from swagger_client.models.instances_instance_id_body import InstancesInstanceIdBody
from swagger_client.models.node_map import NodeMap
from swagger_client.models.node_map_inner import NodeMapInner
from swagger_client.models.quota import Quota
from swagger_client.models.resource import Resource
from swagger_client.models.test_instance_instance_id_body import TestInstanceInstanceIdBody
